==> haskell-drbg-0.5.5-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-2MYeKxKNAAg9AG9fYfGMyc
key: DRBG-0.5.5-2MYeKxKNAAg9AG9fYfGMyc
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: 059240435c5aeced073656888e338a40
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.4.3/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-2MYeKxKNAAg9AG9fYfGMyc
depends:
    base-4.11.1.0 cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    bytestring-0.10.8.2 prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU
    cryptohash-cryptoapi-0.1.4-JRClScjihFD7DtPBfhkIJH
    parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE mtl-2.2.2
    cipher-aes128-0.7.0.3-Ejqf5GqoGyXDPeh4UB2Az1
    entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI=942d5299484d2a2b1e170c366961bcd8
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=a77bb2a04ac30650821b1fe6972fa094
             crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU=6900b771227d4e4da26f3f5981befd1d
             cryptohash-cryptoapi-0.1.4-JRClScjihFD7DtPBfhkIJH=35e3aaa75c3b271a67e774954d104bed
             parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE=71fbc58d940f1d79d8c382c7209c2ee9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             cipher-aes128-0.7.0.3-Ejqf5GqoGyXDPeh4UB2Az1=f20f3c394b806f6d07ecbfe431390ec7
             entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v=bbba9b47b66235cbe49005ce0f2ca1a5
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-drbg-0.5.5-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-6JFCzscKfLG5oAyJGvC8ea
key: DRBG-0.5.5-6JFCzscKfLG5oAyJGvC8ea
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: 72844c7d139f6ea22e8a7b750fbc7859
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.4.3/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-6JFCzscKfLG5oAyJGvC8ea
depends:
    base-4.11.1.0 cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    bytestring-0.10.8.2 prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ
    cryptohash-cryptoapi-0.1.4-LLl0AFoE1nL2yTRkSHOWxj
    parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS mtl-2.2.2
    cipher-aes128-0.7.0.3-1yQsnzuJBsh9H6rqUKKhzx
    entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI=942d5299484d2a2b1e170c366961bcd8
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ=ce10e49cbca1b74596de9d427ce328a8
             cryptohash-cryptoapi-0.1.4-LLl0AFoE1nL2yTRkSHOWxj=9a507afafc16d533209cf3d2a5d4704e
             parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS=bfa6d2c22d7e7c439a84add8c91d8e7a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             cipher-aes128-0.7.0.3-1yQsnzuJBsh9H6rqUKKhzx=27077822fa91efcddcc40b39fc556293
             entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v=bbba9b47b66235cbe49005ce0f2ca1a5
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
